@@ -190,9 +190,7 @@ fa = {
         "لجن",
         "لخت",
         "لختی",
-        "لر",
         "لز",
-        "مادر جنده",
         "مادرجنده",
         "مادرسگ",
         "مادرقهوه",
